/* $Id: hello-object.h,v 1.3 2000/05/23 16:43:08 cactus Exp $ */
/*
  Bonobo-Hello Copyright (C) 2000 RDI Gerg <cactus@cactus.rulez.org>
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License version 2
  (included in the RadioActive distribution in doc/GPL) as published by
  the Free Software Foundation.
  
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
  
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
*/

#ifndef HELLO_OBJECT_H
#define HELLO_OBJECT_H

#include <bonobo.h>
#include "hello-model.h"

BonoboEmbeddableFactory *factory;

BonoboObject *hello_object_factory (BonoboEmbeddableFactory * this,
				    void *data);

#endif
